import pyutil
import unittest

class TestPyUtil(unittest.TestCase):

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_enum(self):
        Wizard = pyutil.enum(MERLIN=1, GANDALF=2, SEVERUS_SNAPE=3, RINCEWIND=4, RAND_ALTHOR=5)
        self.assertIsInstance(Wizard, type)
        self.assertEqual(1, Wizard.MERLIN)
        self.assertEqual(2, Wizard.GANDALF)
        self.assertEqual(3, Wizard.SEVERUS_SNAPE)
        self.assertEqual(4, Wizard.RINCEWIND)
        self.assertEqual(5, Wizard.RAND_ALTHOR)


if __name__ == '__main__':
    unittest.main(verbosity=2)



from django import template

register = template.Library()

@register.filter(name='getkey')
def getkey(value, arg):
    ''' Gets a value from a dict by key.  This allows keys to contain spaces, dashes, etc. '''
    return value.get(arg, '')



# from http://stackoverflow.com/questions/4581789/how-do-i-get-user-ip-address-in-django
def get_client_ip(request):
    x_forwarded_for = request.META.get('HTTP_X_FORWARDED_FOR')
    if x_forwarded_for:
        ip = x_forwarded_for.split(',')[0].strip()
    else:
        ip = request.META.get('REMOTE_ADDR')
    return ip



from contextdecorator import ContextDecorator
from django.core.cache import cache
from requests.exceptions import Timeout
import json
import logging
import requests

logger = logging.getLogger('caldwellpy')

class prime_cache(ContextDecorator):

    def __init__(self, cache_key, data_source, expire=60*60*24, timeout=10.0):
        self.cache_key = cache_key
        self.data_source = data_source
        self.expire = expire
        self.timeout = timeout

    def __enter__(self):
        data = cache.get(self.cache_key)

        if not data:
            try:
                resp = requests.get(self.data_source, timeout=self.timeout)

                if resp.status_code == requests.codes.ok:
                    data = json.loads(resp.text)
                else:
                    logger.error('connection failed for url[%s] code[%s] msg[%s]' % (
                        self.data_source, resp.status_code, resp.text))

                data = json.loads(requests.get(self.data_source).text)
                cache.set(self.cache_key, data, self.expire)
            except Timeout:
                logger.error('connection timeout for url[%s]' % self.data_source)

        return self

    def __exit__(self, type, value, traceback):
        return False



from datetime import datetime

def unix_time(dt):
    epoch = datetime.utcfromtimestamp(0)
    delta = dt - epoch
    try:
        total_seconds = delta.total_seconds()
    except: # python < 2.7
        total_seconds = delta.days * 86400 + delta.seconds + delta.microseconds / 1e6
    return total_seconds

def unix_time_millis(dt):
    return unix_time(dt) * 1000.0



#!/usr/bin/env python

from distutils.core import setup

setup(name='caldwellpy',
      version='1.4.8',
      description='Python Utilities Collection',
      author='Matt Caldwell',
      author_email='matt.caldwell@gmail.com',
      url='https://github.com/mattcaldwell/pyutil',
      packages=['pyutil', 'pyutil.django', 'pyutil.django.templatetags'],
      install_requires=[
          'Django==1.4.5',
          'contextdecorator==0.10.0',
          'mock==1.0.1',
          'requests==1.2.3',
          'wsgiref==0.1.2',
      ]
)
